import textwrap


def speech_bubble(text: str | list):
    max_length = 35

    top_line = "_" * max_length
    print("\n", top_line.rjust(52))
    print("/".rjust(18), "\ ".rjust(37), sep="", end="\n")

    if isinstance(text, str):
        wrapped_text = []
        split_text = text.split(", ")
        for i in split_text:
            wrapped_text.append(textwrap.wrap(i, max_length))
        # print(wrapped_text)

        for i in wrapped_text:
            print("|".rjust(17), "    ", i[0], "|".rjust(34 - len(i[0])), sep="")

    else:
        print("|".rjust(17), "The ISS is over: ".rjust(25), "|".rjust(13), sep="")
        print(
            "|".rjust(17),
            text[0].rjust(8 + len(text[0])),
            "|".rjust(30 - len(text[0])),
            sep="",
        )
        print("|".rjust(17), "As of: ".rjust(15), text[1], "|".rjust(11), sep="")

    print("\\".rjust(18), ("_" * (max_length - 2)).rjust(35), "/", sep="", end="")



import typer
from typing import Optional
from dotenv import load_dotenv

from spacesay.location import iss_location
from spacesay.speech import speech_bubble


load_dotenv()  # Export dotenv into enviroment


astronaut = """
                 | /                 
        _____    // 
      .'     '.  v   _ 
     /    .-""-\   _/ \ 
   .-|   /:.   |  |   |
   |  \  |:.   /.-'-./ 
   | .-'-;:__.'    =/  
   .'=  *=|NASA _.='   
  /   _.  |    ;       
 ;-.-'|    \   |       
/   | \    _\  _\      
\__/'._;.  ==' ==\     
         \    \   |    
         /    /   /    
         /-._/-._/     
         \   `\  \     
          `-._/._/
          """


app = typer.Typer()


@app.command()
def main(text: Optional[str] = typer.Argument(None)):
    if text is None:
        location_time = iss_location()
        speech_bubble(location_time)

    else:
        speech_bubble(text)

    print(astronaut)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['spacesay']

package_data = \
{'': ['*']}

install_requires = \
['python-dotenv>=0.21.1,<0.22.0',
 'requests>=2.28.2,<3.0.0',
 'typer[all]>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['spacesay = spacesay.main:app']}

setup_kwargs = {
    'name': 'spacesay',
    'version': '0.1.0',
    'description': 'A CLI spaceman tells you where the ISS is!',
    'long_description': '# Spacesay\n\nA python reimagining of cowsay.\n\nHave a astronaut say something, or let it tell you where the ISS is currently!\n\n',
    'author': 'AlgorithmEnigma',
    'author_email': 'me@jordanlowell.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



import os
import requests
import time
from datetime import date


def iss_location() -> list[str]:
    # Request ISS location from open-notify
    try:
        r = requests.get("http://api.open-notify.org/iss-now.json").json()

        iss_position = r["iss_position"]

        # Set latitude and logitude values
        lat = iss_position["latitude"]
        lng = iss_position["longitude"]
        # print(lat, lng, sep=", ")

        # Get date from the timestamp
        timestamp = r["timestamp"]
        timestamp = time.ctime(timestamp)[4:-8]
        # last_update = date.fromtimestamp(timestamp).isoformat()

    except requests.exceptions.RequestException as err:
        raise err

    # Attempt to find nearby toponym
    try:
        url_nearby = "http://api.geonames.org/findNearbyJSON"
        querystring_geonames = {
            "lat": {lat},
            "lng": {lng},
            "username": os.environ.get("GEONAMES_USERNAME"),
        }

        responce_geonames = requests.request(
            "GET", url_nearby, params=querystring_geonames
        ).json()

        if len(responce_geonames["geonames"]) >= 1:
            return [responce_geonames["geonames"][0]["adminName1"], timestamp]

    except requests.exceptions.RequestException as err:
        raise err

    # If toponyn not found assume in ocean and find what ocean
    if len(responce_geonames["geonames"]) == 0:
        try:
            url_ocean = "http://api.geonames.org/oceanJSON"

            responce_ocean = requests.request(
                "GET", url_ocean, params=querystring_geonames
            ).json()
            return [responce_ocean["ocean"]["name"], timestamp]
        except requests.exceptions.RequestException as err:
            raise err

    return ["ISS not found", str(date.today())]
